@@ -49,6 +49,7 @@ def configure(file_name):
 # Initializes all GUI widgets
 class MainInterface:
     def __init__(self):
+        padding=5
         self.window = Toplevel()
         folder = Frame(self.window)
         folder.grid(row=0, column=1, sticky=N)
@@ -58,16 +59,16 @@ class MainInterface:
         self.button_frame.grid(row=1, column=0)
 
         self.frameNumber = Label(self.button_frame, text="Frame number")
-        self.frameNumber.grid(row=0, column=1)
+        self.frameNumber.grid(row=0, column=1, padx=padding)
         self.forward = Button(self.button_frame, text=">",
                               command=lambda: load_frame(current_frame_number+1, self.window, self.fbox))
-        self.forward.grid(row=1, column=3, sticky=E)
+        self.forward.grid(row=1, column=3, sticky=E, padx=padding)
         self.forward = Button(self.button_frame, text=">>",
                               command=lambda: load_frame(len(frames_in) - 1, self.window, self.fbox))
-        self.forward.grid(row=1, column=4, sticky=E)
+        self.forward.grid(row=1, column=4, sticky=E, padx=padding)
         self.back = Button(self.button_frame, text="<",
                            command=lambda: load_frame(current_frame_number-1, self.window, self.fbox))
-        self.back.grid(row=1, column=1, sticky=W)
+        self.back.grid(row=1, column=1, sticky=W, padx=padding)
         self.back = Button(self.button_frame, text="<<", command=lambda: load_frame(0, self.window, self.fbox))
         self.back.grid(row=1, column=0, sticky=W)
 
@@ -105,11 +106,11 @@ class MainInterface:
         self.cbDic = {}
 
         for i in range(len(columns)):
+            print(behaviors[i])
             self.cbDic[columns[i]] = IntVar(value = behaviors[i])
 
         for key in self.cbDic:
-            checkbox = Checkbutton(self.check_frame, text=key, variable=self.cbDic[key],
-                                   command=lambda: set_values(self.cbDic))
+            checkbox = Checkbutton(self.check_frame, text=key, variable=self.cbDic[key], command=lambda: set_values(self.cbDic))
             checkbox.grid(sticky=W)
 
         # Save Button
