@@ -16,10 +16,9 @@ def plotsklearnresult(configini,videoSetting, frameSetting):
         config.read(configFile)
     except MissingSectionHeaderError:
         print('ERROR:  Not a valid project_config file. Please check the project_config.ini path.')
-    csv_dir = config.get('General settings', 'csv_path')
-    csv_dir_in = os.path.join(csv_dir, "machine_results")
     animalsNo = config.getint('General settings', 'animal_no')
     projectPath = config.get('General settings', 'project_path')
+    csv_dir_in = os.path.join(projectPath, 'csv', "machine_results")
     frames_dir_out = config.get('Frame settings', 'frames_dir_out')
     frames_dir_out = os.path.join(frames_dir_out, 'sklearn_results')
     poseConfSetting = config.get('create ensemble settings', 'pose_estimation_body_parts')
@@ -31,7 +30,7 @@ def plotsklearnresult(configini,videoSetting, frameSetting):
     mulltiAnimalIDList = mulltiAnimalIDList.split(",")
     if mulltiAnimalIDList[0] != '':
         mulltiAnimalStatus = True
-    if  mulltiAnimalIDList[0] == '':
+    if mulltiAnimalIDList[0] == '':
         mulltiAnimalStatus = False
     print(mulltiAnimalStatus)
     vidinfDf = pd.read_csv(vidInfPath)
@@ -95,12 +94,15 @@ def plotsklearnresult(configini,videoSetting, frameSetting):
             animalBpHeaderList.append(animal1_BPsX.columns[i])
             animalBpHeaderList.append(animal1_BPsY.columns[i])
         animalBpHeaderListX, animalBpHeaderListY, animalBpHeaderList = ([x for x in animalBpHeaderListX if "Tail_end" not in x], [x for x in animalBpHeaderListY if "Tail_end" not in x], [x for x in animalBpHeaderList if "Tail_end" not in x])
+
         if (animalsNo == 2) and (poseConfSetting == 'user_defined'):
             animal_1_BpHeaderList = [s for s in animalBpHeaderList if mulltiAnimalIDList[0] in s]
             animal_2_BpHeaderList = [s for s in animalBpHeaderList if mulltiAnimalIDList[1] in s]
-        if (animalsNo == 2) and (poseConfSetting != 'user_defined'):
+        elif (animalsNo == 2) and (poseConfSetting != 'user_defined'):
             animal_1_BpHeaderList = [s for s in animalBpHeaderList if '_1_' in s]
             animal_2_BpHeaderList = [s for s in animalBpHeaderList if '_2_' in s]
+        else:
+            animal_1_BpHeaderList = animalBpHeaderList.copy()
         if os.path.exists(os.path.join(projectPath,'videos', CurrentVideoName.replace('.csv', '.mp4'))):
             videoPathName = os.path.join(projectPath,'videos', CurrentVideoName.replace('.csv', '.mp4'))
         elif os.path.exists(os.path.join(projectPath,'videos', CurrentVideoName.replace('.csv', '.avi'))):
@@ -117,7 +119,7 @@ def plotsklearnresult(configini,videoSetting, frameSetting):
         if height >= width:
             videoHeight, videoWidth = height, width
         writer = cv2.VideoWriter(outputFileName.replace('.csv', '.mp4'), fourcc, fps, (videoWidth, videoHeight))
-        mySpaceScale, myRadius, myResolution, myFontScale  = 60, 12, 1500, 1.5
+        mySpaceScale, myRadius, myResolution, myFontScale = 60, 12, 1500, 1.5
         maxResDimension = max(width, height)
         circleScale, fontScale, spacingScale = int(myRadius / (myResolution / maxResDimension)), float(myFontScale / (myResolution / maxResDimension)), int(mySpaceScale / (myResolution / maxResDimension))
         currRow = 0
@@ -132,7 +134,7 @@ def plotsklearnresult(configini,videoSetting, frameSetting):
                     currAnimal1 = np.reshape(currAnimal1, (-1, 2))
                     M1polyglon_array_hull = cv2.convexHull((currAnimal1.astype(int)))
                     cv2.drawContours(frame, [M1polyglon_array_hull.astype(int)], 0, (255, 255, 255), 2)
-                if animalsNo == 2 and (poseConfSetting != 'user_defined'):
+                if (animalsNo == 2) and (poseConfSetting != 'user_defined'):
                     currAnimal1, currAnimal2 = (currentDf.loc[currentDf.index[currRow], animal_1_BpHeaderList],currentDf.loc[currentDf.index[currRow], animal_2_BpHeaderList])
                     currAnimal1, currAnimal2  = (np.array(currAnimal1).astype(int), np.array(currAnimal2).astype(int))
                     currAnimal1, currAnimal2 = (np.reshape(currAnimal1, (-1, 2)), np.reshape(currAnimal2, (-1, 2)))
@@ -144,18 +146,19 @@ def plotsklearnresult(configini,videoSetting, frameSetting):
                     currYval = animal1_BPsY.loc[animal1_BPsY.index[currRow], animalBpHeaderListY[cords]]
                     if animalBpHeaderListX[cords] in animal_1_BpHeaderList:
                         color = colorList_animal_1[cords]
-                    if animalBpHeaderListX[cords] in animal_2_BpHeaderList:
+                    elif animalBpHeaderListX[cords] in animal_2_BpHeaderList:
                         color = colorList_animal_2[cords]
                     cv2.circle(frame, (int(currXval), int(currYval)), circleScale, color, -1, lineType=cv2.LINE_AA)
                     if (mulltiAnimalStatus == True) and ('Center' in animalBpHeaderListX[cords]) and (animalBpHeaderListX[cords] in animal_1_BpHeaderList):
                         IDlabelLoc.append([currXval, currYval])
                     if (mulltiAnimalStatus == True) and ('Center' in animalBpHeaderListX[cords]) and (animalBpHeaderListX[cords] in animal_2_BpHeaderList):
                         IDlabelLoc.append([currXval, currYval])
-                if not IDlabelLoc:
+                if (not IDlabelLoc) and (mulltiAnimalStatus == True):
                     animal1_x, animal1_y = currentDf.at[currRow, animal_1_BpHeaderList[0]], currentDf.at[currRow, animal_1_BpHeaderList[1]]
-                    animal2_x, animal2_y = currentDf.at[currRow, animal_2_BpHeaderList[0]], currentDf.at[currRow, animal_2_BpHeaderList[1]]
                     IDlabelLoc.append([animal1_x, animal1_y])
-                    IDlabelLoc.append([animal2_x, animal2_y])
+                    if animalsNo == 2:
+                        animal2_x, animal2_y = currentDf.at[currRow, animal_2_BpHeaderList[0]], currentDf.at[currRow, animal_2_BpHeaderList[1]]
+                        IDlabelLoc.append([animal2_x, animal2_y])
                 if height < width:
                     frame = ndimage.rotate(frame, 90)
                     rotationFlag = True
@@ -168,7 +171,6 @@ def plotsklearnresult(configini,videoSetting, frameSetting):
                         newX2, newY2 = abs(int(IDlabelLoc[1][0] * cos(a) + IDlabelLoc[1][1] * sin(a))), int(frame.shape[0] - int(((-IDlabelLoc[1][1]) * cos(a) + IDlabelLoc[1][0] * sin(a))))
                         cv2.putText(frame, str(mulltiAnimalIDList[0]), (newX1, newY1), cv2.FONT_HERSHEY_COMPLEX, fontScale, (0,0,255), 4)
                         cv2.putText(frame, str(mulltiAnimalIDList[1]), (newX2, newY2), cv2.FONT_HERSHEY_COMPLEX, fontScale, (255,0,0), 4)
-
                 # draw event timers
                 for b in range(counters_no):
                     target_timers[b] = (1 / fps) * target_counters[b]
@@ -198,7 +200,7 @@ def plotsklearnresult(configini,videoSetting, frameSetting):
                     break
                 currRow+=1
                 print('Frame ' + str(currRow) + '/' + str(frames) + '. Video ' + str(loopy) + '/' + str(len(filesFound)))
-            if (frame is None) or currRow >= 17000:
+            if frame is None:
                 print('Video ' + str(os.path.basename(CurrentVideoName.replace('.csv', '.mp4'))) + ' saved.')
                 cap.release()
                 break
